package VMOMI::EventAlarmExpressionComparisonOperator;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
